@@ -3,6 +3,8 @@
 里面提供了丰富的工具方法包括setup文件创建README.MD文件的创建，账号输入等一系列工具方法
 '''
 import os
+from setuptools import setup
+import setuptools
 class PyPiTools:
     '''
     创建setup.py文件
@@ -16,6 +18,21 @@ class PyPiTools:
             pass
         else:
             open('README.md', 'w').close()
+    @staticmethod
+    def setupconfig(name='PypiPro',version='1.0.0',**config):
+        if  config:
+            return config
+        else:
+            return {
+            "name":name,
+            "version":version,
+            "packages" : setuptools.find_packages(),
+            "author" : "robin",
+            "author_email" : "xiaoyaojianxians@163.com",
+            "install_requires" : ['twine', 'wheel','setuptools'],  # 依赖的包
+            "python_requires" : '>=3'
+        # python版本大于3
+        }
 
     @staticmethod
     def buildSetupFile():
@@ -56,11 +73,13 @@ class PyPiTools:
 
 
 
+
+
     '''文档说明'''
     @staticmethod
     def showdoc():
         '''函数方法说明'''
-        doc='''
+        return '''
         此工具用于构建自己的包上传到pypi，步骤是先创建属于自己的包项目结构如下:
         projectname
              |-----packgename
